@@ -2,7 +2,8 @@ import sqlite3
 
 
 class Delete:
-    def __init__(self, table_name, db_path):
+    def __init__(self, model_in, table_name, db_path):
+        self.model_in = model_in
         self.table_name = table_name
         self.db_path = db_path
 
@@ -17,3 +18,4 @@ class Delete:
         c.execute(query, tuple(params))
         conn.commit()
         conn.close()
+        self.model_in.load_querrys(self.model_in)
