@@ -2,7 +2,8 @@ import sqlite3
 
 
 class Insert:
-    def __init__(self, table_name, db_path):
+    def __init__(self, model_in, table_name, db_path):
+        self.model_in = model_in
         self.table_name = table_name
         self.db_path = db_path
         self.get_columns()
@@ -30,3 +31,5 @@ class Insert:
         c = conn.cursor()
         c.execute(f"INSERT INTO {self.table_name} ({add_to_columns}) VALUES ({params_str})", tuple(params))
         conn.commit()
+        conn.close()
+        self.model_in.load_querrys(self.model_in)
