@@ -2,7 +2,8 @@ import sqlite3
 
 
 class Where:
-    def __init__(self, table_name, db_path, query, params):
+    def __init__(self, model_in, table_name, db_path, query, params):
+        self.model_in = model_in
         self.table_name = table_name
         self.db_path = db_path
         self.query = query
@@ -19,13 +20,12 @@ class Where:
         c.execute(self.query, self.params)
         conn.commit()
         conn.close()
-
-
-
+        self.model_in.load_querrys(self.model_in)
 
 
 class Update:
-    def __init__(self, table_name, db_path):
+    def __init__(self, model_in, table_name, db_path):
+        self.model_in = model_in
         self.table_name = table_name
         self.db_path = db_path
         self.get_columns()
@@ -46,4 +46,4 @@ class Update:
             self.query += f"{column} = ?, "
             self.params.append(kwargs[column])
         self.query = self.query[:len(self.query) - 2]
-        return Where(self.table_name, self.db_path, self.query, self.params)
+        return Where(self.model_in, self.table_name, self.db_path, self.query, self.params)
